@@ -7,14 +7,11 @@ __all__ = [
     'as_a',
     'to',
     'step',
-    'INF',
     'has',
     'take',
     'drop',
 ]
 
-INF = float('inf')
-
 def flip(fn):
     def wrapper(*args):
         return fn(args[1], args[0])
